@@ -67,9 +67,9 @@ def create_response(
     )
 
 
-def success_response(data: T | Any = None, code: int = 0) -> JSONResponse:
+def success_response(data: T | Any = None, code: int = 0, message: str = None) -> JSONResponse:
     """快捷创建成功响应（code=0, success=True）"""
-    return create_response(data=data, code=code)
+    return create_response(data=data, code=code, message=message)
 
 
 def error_response(
